#ifndef _STM32YYXX_LL_PKA_H_
#define _STM32YYXX_LL_PKA_H_
/* LL raised several warnings, ignore them */
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wunused-parameter"
#pragma GCC diagnostic ignored "-Wstrict-aliasing"

#ifdef STM32L4xx
  #include "stm32l4xx_ll_pka.h"
#endif
#ifdef STM32L5xx
  #include "stm32l5xx_ll_pka.h"
#endif
#ifdef STM32WBxx
  #include "stm32wbxx_ll_pka.h"
#endif
#pragma GCC diagnostic pop
#endif /* _STM32YYXX_LL_PKA_H_ */
